"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseConfig = exports.readConfig = exports.possibleFilenames = void 0;
const path_1 = __importDefault(require("path"));
const log_1 = require("../util/log");
const defaults_1 = require("./defaults");
exports.possibleFilenames = [
    'declarator.js',
    'declarator.json',
    '.declarator.js',
    '.declarator.json',
    '.declaratorrc',
    '.declaratorrc.js',
    '.declaratorrc.json'
];
async function readConfig(root = process.cwd()) {
    for (const possibleFile of exports.possibleFilenames) {
        const name = path_1.default.join(root, possibleFile);
        try {
            return require(name);
        }
        catch {
            log_1.log.debug `${name} could not be found.`;
            // no empty block
            continue;
        }
    }
    // Try finding it at package.json
    const packagePath = path_1.default.join(root, 'package.json');
    try {
        const packageJson = await require(packagePath);
        const declarator = packageJson['declarator'];
        if (!declarator) {
            log_1.log.debug `${packagePath} does not contain a declarator section.`;
            // Skips to catch block
            throw null;
        }
        return declarator;
    }
    catch (err) {
        // no config found.
        log_1.log.info `No config file could be found. Tried (${exports.possibleFilenames})`;
        return defaults_1.defaultOptions;
    }
}
exports.readConfig = readConfig;
function parseConfig(config) {
    return typeof config === 'function' ? config() : config;
}
exports.parseConfig = parseConfig;
//# sourceMappingURL=reader.js.map